@@ -23,7 +23,7 @@ for lang in languages:
 gettext.bindtextdomain (APP_NAME, I18N_DIR)
 gettext.textdomain (APP_NAME)
 def _(msg, language=None):
-    if language == None or not LANGUAGE_PACK.has_key(language):
+    if language == None or language not in LANGUAGE_PACK:
         return gettext.gettext(msg)
     else:
         return LANGUAGE_PACK[language].gettext(msg)
